run: Don't kill children twice.
[dss.git] / snap.c
diff --git a/snap.c b/snap.c
index aef0c51203a26b35233ed811f0fb498aa5ec5967..8de76d459da1a8844a452fa576d706014b229be9 100644 (file)
--- a/snap.c
+++ b/snap.c
@@ -1,8 +1,4 @@
-/*
- * Copyright (C) 2008-2010 Andre Noll <maan@systemlinux.org>
- *
- * Licensed under the GPL v2. For licencing details see COPYING.
- */
+/* SPDX-License-Identifier: GPL-2.0 */
 #include <stdlib.h>
 #include <assert.h>
 #include <inttypes.h>
@@ -84,7 +80,7 @@ static int is_snapshot(const char *dirname, int64_t now, int unit_interval,
        }
        if (!strcmp(dash + 1, "incomplete.being_deleted")) {
                s->completion_time = -1;
-               s->flags = SS_BEING_DELETED; /* mot cpmplete, being deleted */
+               s->flags = SS_BEING_DELETED; /* not complete, being deleted */
                goto success;
        }
        tmp = dash + 1;
@@ -232,3 +228,13 @@ __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl)
        return name;
 }
 
+int num_complete_snapshots(struct snapshot_list *sl)
+{
+       struct snapshot *s;
+       int i, ret = 0;
+
+       FOR_EACH_SNAPSHOT(s, i, sl)
+               if (s->flags & SS_COMPLETE)
+                       ret++;
+       return ret;
+}